@@ -456,6 +456,59 @@ class ArgsUtils:
 
         return a_result
 
+#
+# Processes Utils
+#
+# Author: Carles Mateo
+# Creation Date: 2014-11-11 18:18 Barcelona
+# Last Update: 2021-04-10 11:15 Ireland
+# Description: Class to deal with Python functionalities and compatibility
+#
+
+
+class PythonUtils:
+
+    def get_python_version(self):
+        """
+        Returns the version of Python
+
+        Examples:
+        sys.version_info(major=2, minor=7, micro=18, releaselevel='final', serial=0)
+        sys.version_info(major=3, minor=8, micro=5, releaselevel='final', serial=0)
+        :return: s_version, i_major, i_minor, i_micro, s_releaselevel
+        """
+
+        # This only works with Python3, so changing to compatible Python2 and Python3
+        # i_major = sys.version_info["major"]
+        # i_minor = sys.version_info["minor"]
+        # i_micro = sys.version_info["micro"]
+
+        i_major = sys.version_info[0]
+        i_minor = sys.version_info[1]
+        i_micro = sys.version_info[2]
+
+        s_releaselevel = sys.version_info[3]
+
+        s_version = str(i_major) + "." + str(i_minor) + "." + str(i_micro)
+
+        return s_version, i_major, i_minor, i_micro, s_releaselevel
+
+    def is_python_2(self):
+        s_version, i_major, i_minor, i_micro, s_releaselevel = self.get_python_version()
+
+        if i_major == 2:
+            return True
+
+        return False
+
+    def is_python_3(self):
+        s_version, i_major, i_minor, i_micro, s_releaselevel = self.get_python_version()
+
+        if i_major == 3:
+            return True
+
+        return False
+
 
 class ScreenUtils:
 
@@ -666,20 +719,15 @@ class ScreenUtils:
 
 class Cmemgzip:
 
-    VERSION = "0.4.2"
+    VERSION = "0.4.3"
 
-    o_fileutils = None
-    o_stringutils = None
-    o_datetime = None
-    o_argutils = None
-    o_screenutils = None
-
-    def __init__(self, o_fileutils, o_stringutils, o_datetime, o_argutils, o_screenutils=ScreenUtils(b_support_colors=True)):
+    def __init__(self, o_fileutils, o_stringutils, o_datetime, o_argutils, o_screenutils=ScreenUtils(b_support_colors=True), o_pythonutils=PythonUtils()):
         self.o_fileutils = o_fileutils
         self.o_stringutils = o_stringutils
         self.o_datetime = o_datetime
         self.o_argutils = o_argutils
         self.o_screenutils = o_screenutils
+        self.o_pythonutils = o_pythonutils
 
     def exit_app(self, s_error_message="", i_error_code=0):
         if s_error_message != "":
@@ -713,10 +761,18 @@ class Cmemgzip:
         b_simulate, i_mem_mb, s_filename = self.validate_parameters_or_exit()
 
         print(self.o_screenutils.color_title("cmemgzip.py v." + Cmemgzip.VERSION))
-        print()
+        # Python 2 requires ("") otherwise it prints ()
+        print("")
+
+        s_python_version, i_major, i_minor, i_micro, s_releaselevel = self.o_pythonutils.get_python_version()
+        print("Detected Python: " + s_python_version)
+        if self.o_pythonutils.is_python_2() is True:
+            self.o_screenutils.perror("Python 2 is not supported.")
+            self.exit_app("Minimum version is Python 3.5", i_error_code=1)
+
         if b_simulate is True:
             self.d_p("Running in Simulate / Dry-Run mode. No file will be deleted or written.")
-            print()
+            print("")
 
         self.compress(s_filename, b_simulate, i_mem_mb)
 
@@ -727,9 +783,6 @@ class Cmemgzip:
         :return: b_simulate, i_mem_mb, s_filename
         """
 
-        b_success_mem = True
-        i_mem_mb = 0
-
         b_black, s_value_black = self.o_argutils.get_arg_from_list(["-b", "--black-and-white"])
         if b_black is True:
             # Override Screenutils
@@ -822,7 +875,6 @@ class Cmemgzip:
             if b_success_compression is False:
                 self.exit_app("Error! There has been a problem compressing the file.", i_error_code=1)
 
-
         # Give a chance to free the memory from the uncompressed file
         by_file_contents = None
 
@@ -1092,8 +1144,9 @@ def main_cmemgzip():
     o_argutils = ArgsUtils()
     o_timeutils = DateTimeUtils()
     o_screenutils = ScreenUtils(b_support_colors=b_support_colors)
+    o_pythonutils = PythonUtils()
 
-    o_cmemgzip = Cmemgzip(o_fileutils, o_stringutils, o_timeutils, o_argutils, o_screenutils)
+    o_cmemgzip = Cmemgzip(o_fileutils, o_stringutils, o_timeutils, o_argutils, o_screenutils, o_pythonutils)
     try:
         o_cmemgzip.main()
     except KeyboardInterrupt:
